FlutterSecureStorageSettings class

Constructors

FlutterSecureStorageSettings({String keyPrefix = '', bool encrypt = true, bool encryptedSharedPreferences = true, KeychainAccessibility iosAccessibility = KeychainAccessibility.first_unlock})
const

Properties

encrypt bool
final
encryptedSharedPreferences bool
Android
final
hashCode int
The hash code for this object.
no setterinherited
iosAccessibility → KeychainAccessibility
iOS
final
keyPrefix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited